@@ -198,10 +198,13 @@ class Future(AbstractFuture):
 
 
 class SearchFuture(Future):
+    def __init__(self, future, done_callback=None, auto_id=True):
+        super().__init__(future, done_callback)
+        self._auto_id = auto_id
 
     def on_response(self, response):
         if response.status.error_code == 0:
-            return QueryResult(response)
+            return QueryResult(response, self._auto_id)
 
         status = response.status
         raise BaseException(status.error_code, status.reason)
