@@ -587,9 +587,11 @@ class GrpcHandler(AbsMilvus):
         request = Prepare.search_request(collection_name, query_entities, partition_tags, fields)
         self._search_hook.pre_search()
         ft = self._stub.Search.future(request, wait_for_ready=True, timeout=to)
+        collection_schema = self.describe_collection(collection_name=collection_name)
+        auto_id = collection_schema["auto_id"]
         if kwargs.get("_async", False) is True:
             func = kwargs.get("_callback", None)
-            return SearchFuture(ft, func)
+            return SearchFuture(ft, func, auto_id)
 
         response = ft.result()
         self._search_hook.aft_search()
@@ -600,9 +602,6 @@ class GrpcHandler(AbsMilvus):
         if response.status.error_code != 0:
             raise BaseException(response.status.error_code, response.status.reason)
 
-        collection_schema = self.describe_collection(collection_name=collection_name)
-        auto_id = collection_schema["auto_id"]
-
         # TODO: handler response
         # resutls = self._search_hook.handle_response(response)
 
@@ -698,7 +697,7 @@ class GrpcHandler(AbsMilvus):
             return None
         raise BaseException(status.error_code, status.reason)
 
-    @error_handler(common_types.IndexState.FAILED)
+    @error_handler(common_types.IndexState.INDEX_STATE_FAILED)
     def get_index_state(self, collection_name, field_name, timeout=None, **kwargs):
         request = Prepare.get_index_state_request(collection_name, field_name)
         rf = self._stub.GetIndexState.future(request, wait_for_ready=True, timeout=timeout)
@@ -715,9 +714,9 @@ class GrpcHandler(AbsMilvus):
             print("\n***********  waiting for building index ***********\n")
             try:
                 state = self.get_index_state(collection_name, field_name, timeout, **kwargs)
-                if state == common_types.IndexState.FINISHED:
+                if state == common_types.IndexState.INDEX_STATE_FINISHED:
                     return True
-                if state == common_types.IndexState.FAILED:
+                if state == common_types.IndexState.INDEX_STATE_FAILED:
                     return False
             except BaseException:
                 return False
@@ -748,7 +747,7 @@ class GrpcHandler(AbsMilvus):
             time.sleep(0.5)
 
             for info in self.get_query_segment_infos(collection_name, timeout):
-                if 0 < unloaded_segments.get(info.segmentID, 0) <= info.num_rows:
+                if 0 <= unloaded_segments.get(info.segmentID, -1) <= info.num_rows:
                     unloaded_segments.pop(info.segmentID)
 
     @error_handler()
@@ -812,7 +811,7 @@ class GrpcHandler(AbsMilvus):
             time.sleep(0.5)
 
             for info in self.get_query_segment_infos(collection_name, timeout):
-                if  0 < unloaded_segments.get(info.segmentID, 0) <= info.num_rows:
+                if 0 <= unloaded_segments.get(info.segmentID, -1) <= info.num_rows:
                     unloaded_segments.pop(info.segmentID)
 
     @error_handler()
