@@ -639,13 +639,3 @@ class HttpHandler(ConnectIntf):
         response = rq.put(url, ujson.dumps(request), headers=headers)
         result = response.json()
         return Status(result["code"], result["message"])
-
-    @handle_error()
-    def compact(self, table_name, timeout):
-        url = self._uri + "/system/task"
-        headers = {"Content-Type": "application/json"}
-        request = {"compact": {"collection_name": table_name}}
-
-        response = rq.put(url, ujson.dumps(request), headers=headers)
-        result = response.json()
-        return Status(result["code"], result["message"])
