@@ -62,8 +62,10 @@ class ConnectionRecord:
         self._kw = kwargs
 
         if handler == "GRPC":
-            self._register_link()
-            self._connection = GrpcHandler(uri=self._uri, pre_ping=self._pre_ping, conn_id=conn_id, **self._kw)
+            self._connection = GrpcHandler(uri=uri, pre_ping=self._pre_ping, conn_id=conn_id, **self._kw)
+        # if handler == "GRPC":
+        #     self._register_link()
+        #     self._connection = GrpcHandler(uri=self._uri, pre_ping=self._pre_ping, conn_id=conn_id, **self._kw)
         elif handler == "HTTP":
             self._connection = HttpHandler(uri=uri, pre_ping=self._pre_ping)
         else:
