@@ -195,7 +195,6 @@ class Prepare:
         else:
             # field name & type must match fields info
             location = dict()
-
             for i, field in enumerate(fields_info):
                 match_flag = False
                 for j in range(fields_len):
@@ -209,6 +208,21 @@ class Prepare:
                                 raise ParamError("Field type doesn't match. Collection field type is {},"
                                                  "but entities field type is {}".format(field["type"],
                                                                                         entities[j]["type"]))
+                            if entities[j]["type"] in [DataType.FLOAT_VECTOR,]:
+                                import ast
+                                if ast.literal_eval(field["params"]["dim"]) != len(entities[j]["values"][0]):
+                                    raise ParamError("Field type doesn't match. Collection field dim is {},"
+                                                     "but entities field dim is {}"
+                                                     .format(ast.literal_eval(field["params"]["dim"]),
+                                                             len(entities[j]["values"][0])))
+
+                            if entities[j]["type"] in [DataType.BINARY_VECTOR,]:
+                                import ast
+                                if ast.literal_eval(field["params"]["dim"]) != len(entities[j]["values"][0]) * 8:
+                                    raise ParamError("Field type doesn't match. Collection field dim is {},"
+                                                     "but entities field dim is {}"
+                                                     .format(ast.literal_eval(field["params"]["dim"]),
+                                                             len(entities[j]["values"][0]) * 8))
                             location[field["name"]] = j
                             fields_type.append(entities[j]["type"])
                             match_flag = True
@@ -220,6 +234,20 @@ class Prepare:
                                 raise ParamError("Field type doesn't match. Collection field type is {},"
                                                  "but entities field type is {}".format(field["type"],
                                                                                         entities[j]["type"]))
+                            if entities[j]["type"] in [DataType.FLOAT_VECTOR,]:
+                                import ast
+                                if ast.literal_eval(field["params"]["dim"]) != len(entities[j]["values"][0]):
+                                    raise ParamError("Field type doesn't match. Collection field dim is {},"
+                                                     "but entities field dim is {}"
+                                                     .format(ast.literal_eval(field["params"]["dim"]),
+                                                             len(entities[j]["values"][0])))
+                            if entities[j]["type"] in [DataType.BINARY_VECTOR, ]:
+                                import ast
+                                if ast.literal_eval(field["params"]["dim"]) != len(entities[j]["values"][0]) * 8:
+                                    raise ParamError("Field type doesn't match. Collection field dim is {},"
+                                                     "but entities field dim is {}"
+                                                     .format(ast.literal_eval(field["params"]["dim"]),
+                                                             len(entities[j]["values"][0]) * 8))
                             location[field["name"]] = j
                             fields_type.append(entities[j]["type"])
                             match_flag = True
