@@ -8,11 +8,15 @@ from urllib.parse import urlparse
 
 from . import __version__
 from .types import Status
-from .check import check_pass_param, is_legal_host, is_legal_port
+from .check import check_pass_param, is_legal_host, is_legal_port, is_legal_index_metric_type, is_legal_binary_index_metric_type
 from .pool import ConnectionPool, SingleConnectionPool, SingletonThreadPool
 from .exceptions import ParamError, DeprecatedError
 
 from ..settings import DefaultConfig as config
+from .utils import valid_binary_metric_types
+from .utils import valid_index_types
+from .utils import valid_binary_index_types
+from .utils import valid_index_params_keys
 
 LOGGER = logging.getLogger(__name__)
 
@@ -123,7 +127,7 @@ class Milvus:
         self._conn = None
 
     def __del__(self):
-        return self.close()
+        self._pool = None
 
     def _connection(self):
         return self._pool.fetch()
@@ -140,7 +144,10 @@ class Milvus:
         """
         Close client instance
         """
-        self._pool = None
+        if self._pool:
+            self._pool = None
+            return
+        raise Exception("connection was already closed!")
 
     @check_connect
     def create_collection(self, collection_name, fields, timeout=30):
@@ -653,6 +660,34 @@ class Milvus:
         params = params or dict()
         if not isinstance(params, dict):
             raise ParamError("Params must be a dictionary type")
+        # params preliminary validate
+        if 'index_type' not in params:
+            raise ParamError("Params must contains key: 'index_type'")
+        if 'params' not in params:
+            raise ParamError("Params must contains key: 'params'")
+        if 'metric_type' not in params:
+            raise ParamError("Params must contains key: 'metric_type'")
+        if not isinstance(params['params'], dict):
+            raise ParamError("Params['params'] must be a dictionary type")
+        if params['index_type'] not in valid_index_types:
+            raise ParamError("Invalid index_type: " + params['index_type'] +
+                             ", which must be one of: " + valid_index_types)
+        for k in params['params'].keys():
+            if k not in valid_index_params_keys:
+                raise ParamError("Invalid params['params'].key: " + k)
+        for v in params['params'].values():
+            if not isinstance(v, int):
+                raise ParamError("Invalid params['params'].value: " + v + ", which must be an integer")
+
+        # filter invalid metric type
+        if params['index_type'] in valid_binary_index_types:
+            if not is_legal_binary_index_metric_type(params['index_type'], params['metric_type']):
+                raise ParamError("Invalid metric_type: " + params['metric_type'] +
+                                 ", which does not match the index type: " + params['index_type'])
+        else:
+            if not is_legal_index_metric_type(params['index_type'], params['metric_type']):
+                raise ParamError("Invalid metric_type: " + params['metric_type'] +
+                                 ", which does not match the index type: " + params['index_type'])
         with self._connection() as handler:
             return handler.create_index(collection_name, field_name, params, timeout, **kwargs)
 
@@ -795,8 +830,7 @@ class Milvus:
             BaseException: If the return result from server is not ok
         """
         if collection_names in (None, []):
-            with self._connection() as handler:
-                return handler.flush([], timeout, **kwargs)
+            raise ParamError("Collection name list can not be None or empty")
 
         if not isinstance(collection_names, list):
             raise ParamError("Collection name array must be type of list")
