@@ -3,6 +3,44 @@ from ..grpc_gen.milvus_pb2 import SearchResults as Grpc_Result
 from ..client.abstract import QueryResult
 from ..client.exceptions import ParamError
 
+valid_index_types = [
+    "FLAT",
+    "IVF_FLAT",
+    "IVF_SQ8",
+    # "IVF_SQ8_HYBRID",
+    "IVF_PQ",
+    "HNSW",
+    # "NSG",
+    "ANNOY",
+    "RHNSW_FLAT",
+    "RHNSW_PQ",
+    "RHNSW_SQ",
+    "BIN_FLAT",
+    "BIN_IVF_FLAT"
+]
+
+valid_index_params_keys = [
+    "nlist",
+    "m",
+    "nbits",
+    "M",
+    "efConstruction",
+    "PQM",
+    "n_trees"
+]
+
+valid_binary_index_types = [
+    "BIN_FLAT",
+    "BIN_IVF_FLAT"
+]
+
+valid_binary_metric_types = [
+    "JACCARD",
+    "HAMMING",
+    "TANIMOTO",
+    "SUBSTRUCTURE",
+    "SUPERSTRUCTURE"
+]
 
 # def merge_results(results_list, topk, *args, **kwargs):
 #     """
